"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Cell = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
/**
 * cell component - the basic building block of the table
 */
const Cell = ({
  data,
  width,
  height,
  flex,
  style,
  textStyle,
  borderStyle,
  children,
  onPress,
  cellContainer = {},
  ...props
}) => {
  const textDom = children ?? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
    style: _reactNative.StyleSheet.flatten([textStyle]),
    ...props,
    children: data
  });
  const borderTopWidth = borderStyle?.borderWidth ?? 0;
  const borderRightWidth = borderTopWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';
  const composedStyles = (0, _react.useMemo)(() => {
    const styles = {};
    if (width) styles.width = width;
    if (height) styles.height = height;
    if (flex) styles.flex = flex;
    if (!width && !flex && !height && !style) styles.flex = 1;
    return styles;
  }, [width, height, flex, style]);

  // determine whether to apply flex: 1 to cell style
  const cellStyle = (0, _react.useMemo)(() => {
    if (width) {
      return {};
    }
    return styles.cell;
  }, [width]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    ...cellContainer,
    style: _reactNative.StyleSheet.flatten([{
      borderTopWidth,
      borderRightWidth,
      borderColor
    }, composedStyles, style, cellContainer.style, cellStyle]),
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Pressable, {
      style: [styles.cell, style],
      onPress: () => onPress?.(data),
      children: textDom
    })
  });
};
exports.Cell = Cell;
const styles = _reactNative.StyleSheet.create({
  cell: {
    flex: 1
  }
});
//# sourceMappingURL=cell.js.map