"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Rows = exports.Row = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _cell = require("./cell.js");
var _index = require("../util/index.js");
var _jsxRuntime = require("react/jsx-runtime");
/** Row component - Renders a single row of cells*/
const Row = ({
  data,
  style,
  widthArr,
  height,
  flexArr,
  textStyle,
  onPress,
  cellTextStyle,
  ...props
}) => {
  const width = widthArr ? (0, _index.sum)(widthArr) : 0;
  const composedStyle = (0, _react.useMemo)(() => {
    const styles = {};
    if (width) styles.width = width;
    if (height) styles.height = height;
    return styles;
  }, [width, height]);
  if (!data) return null;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: _reactNative.StyleSheet.flatten([composedStyle, styles.row, style]),
    children: data.map((item, i) => {
      const flex = flexArr?.[i];
      const wth = widthArr?.[i];
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_cell.Cell, {
        data: item,
        width: wth,
        height: height,
        flex: flex,
        style: style,
        onPress: onPress,
        textStyle: _reactNative.StyleSheet.flatten([cellTextStyle && cellTextStyle(item), textStyle]),
        ...props
      }, i);
    })
  });
};
exports.Row = Row;
const Rows = ({
  data,
  style,
  widthArr,
  heightArr,
  flexArr,
  textStyle,
  ...props
}) => {
  const flex = flexArr ? (0, _index.sum)(flexArr) : 0;
  const width = widthArr ? (0, _index.sum)(widthArr) : 0;
  const composedStyle = (0, _react.useMemo)(() => {
    const styles = {};
    if (flex) styles.flex = flex;
    if (width) styles.width = width;
    return styles;
  }, [flex, width]);
  return data ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: composedStyle,
    children: data.map((item, i) => {
      const height = heightArr?.[i];
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(Row, {
        data: item,
        widthArr: widthArr,
        height: height,
        flexArr: flexArr,
        style: style,
        textStyle: textStyle,
        ...props
      }, i);
    })
  }) : null;
};
exports.Rows = Rows;
const styles = _reactNative.StyleSheet.create({
  row: {
    flexDirection: 'row',
    overflow: 'hidden'
  }
});
//# sourceMappingURL=rows.js.map