"use strict";

import { useMemo } from 'react';
import { View, Text, StyleSheet, Pressable } from 'react-native';
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * cell component - the basic building block of the table
 */
export const Cell = ({
  data,
  width,
  height,
  flex,
  style,
  textStyle,
  borderStyle,
  children,
  onPress,
  cellContainer = {},
  ...props
}) => {
  const textDom = children ?? /*#__PURE__*/_jsx(Text, {
    style: StyleSheet.flatten([textStyle]),
    ...props,
    children: data
  });
  const borderTopWidth = borderStyle?.borderWidth ?? 0;
  const borderRightWidth = borderTopWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';
  const composedStyles = useMemo(() => {
    const styles = {};
    if (width) styles.width = width;
    if (height) styles.height = height;
    if (flex) styles.flex = flex;
    if (!width && !flex && !height && !style) styles.flex = 1;
    return styles;
  }, [width, height, flex, style]);

  // determine whether to apply flex: 1 to cell style
  const cellStyle = useMemo(() => {
    if (width) {
      return {};
    }
    return styles.cell;
  }, [width]);
  return /*#__PURE__*/_jsx(View, {
    ...cellContainer,
    style: StyleSheet.flatten([{
      borderTopWidth,
      borderRightWidth,
      borderColor
    }, composedStyles, style, cellContainer.style, cellStyle]),
    children: /*#__PURE__*/_jsx(Pressable, {
      style: [styles.cell, style],
      onPress: () => onPress?.(data),
      children: textDom
    })
  });
};
const styles = StyleSheet.create({
  cell: {
    flex: 1
  }
});
//# sourceMappingURL=cell.js.map