"use strict";

import { useMemo } from 'react';
import { View, StyleSheet } from 'react-native';
import { Cell } from "./cell.js";
import { sum } from "../util/index.js";

/** Row component - Renders a single row of cells*/
import { jsx as _jsx } from "react/jsx-runtime";
export const Row = ({
  data,
  style,
  widthArr,
  height,
  flexArr,
  textStyle,
  onPress,
  cellTextStyle,
  ...props
}) => {
  const width = widthArr ? sum(widthArr) : 0;
  const composedStyle = useMemo(() => {
    const styles = {};
    if (width) styles.width = width;
    if (height) styles.height = height;
    return styles;
  }, [width, height]);
  if (!data) return null;
  return /*#__PURE__*/_jsx(View, {
    style: StyleSheet.flatten([composedStyle, styles.row, style]),
    children: data.map((item, i) => {
      const flex = flexArr?.[i];
      const wth = widthArr?.[i];
      return /*#__PURE__*/_jsx(Cell, {
        data: item,
        width: wth,
        height: height,
        flex: flex,
        style: style,
        onPress: onPress,
        textStyle: StyleSheet.flatten([cellTextStyle && cellTextStyle(item), textStyle]),
        ...props
      }, i);
    })
  });
};
export const Rows = ({
  data,
  style,
  widthArr,
  heightArr,
  flexArr,
  textStyle,
  ...props
}) => {
  const flex = flexArr ? sum(flexArr) : 0;
  const width = widthArr ? sum(widthArr) : 0;
  const composedStyle = useMemo(() => {
    const styles = {};
    if (flex) styles.flex = flex;
    if (width) styles.width = width;
    return styles;
  }, [flex, width]);
  return data ? /*#__PURE__*/_jsx(View, {
    style: composedStyle,
    children: data.map((item, i) => {
      const height = heightArr?.[i];
      return /*#__PURE__*/_jsx(Row, {
        data: item,
        widthArr: widthArr,
        height: height,
        flexArr: flexArr,
        style: style,
        textStyle: textStyle,
        ...props
      }, i);
    })
  }) : null;
};
const styles = StyleSheet.create({
  row: {
    flexDirection: 'row',
    overflow: 'hidden'
  }
});
//# sourceMappingURL=rows.js.map