"use strict";

import React from 'react';
import { View, ScrollView, StyleSheet } from 'react-native';
import { Cell } from "./cell.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/** StickyTable component - Table with sticky first column */
export const StickyTable = ({
  data,
  stickyColumnWidth,
  columnWidths = [],
  style,
  cellStyle,
  textStyle,
  headerStyle,
  headerTextStyle,
  borderStyle = {
    borderWidth: 1,
    borderColor: '#000'
  }
}) => {
  if (!data || data.length === 0) return null;

  // calc content width
  const contentWidth = columnWidths.reduce((sum, width) => sum + width, 0);
  return /*#__PURE__*/_jsxs(View, {
    style: [styles.container, style],
    children: [/*#__PURE__*/_jsx(View, {
      style: [styles.stickyColumn, {
        width: stickyColumnWidth
      }],
      children: data.map((row, rowIndex) => {
        const isHeader = rowIndex === 0;
        return /*#__PURE__*/_jsx(View, {
          style: [cellStyle, isHeader && headerStyle, borderStyle && {
            borderTopWidth: borderStyle.borderWidth,
            borderLeftWidth: borderStyle.borderWidth,
            borderBottomWidth: borderStyle.borderWidth,
            borderRightWidth: borderStyle.borderWidth,
            borderColor: borderStyle.borderColor
          }],
          children: /*#__PURE__*/_jsx(Cell, {
            data: row[0],
            width: stickyColumnWidth,
            textStyle: [textStyle, isHeader && headerTextStyle],
            borderStyle: {
              borderWidth: 0
            } // no borders for inner cell
          })
        }, `sticky-${rowIndex}`);
      })
    }), /*#__PURE__*/_jsx(ScrollView, {
      horizontal: true,
      style: styles.scrollView,
      showsHorizontalScrollIndicator: true,
      children: /*#__PURE__*/_jsx(View, {
        style: {
          width: contentWidth || undefined
        },
        children: data.map((row, rowIndex) => {
          const isHeader = rowIndex === 0;
          // skip first column as it's already in the sticky part
          const rowData = row.slice(1);
          return /*#__PURE__*/_jsx(View, {
            style: styles.row,
            children: rowData.map((cellData, cellIndex) => {
              const colWidth = columnWidths[cellIndex];
              return /*#__PURE__*/_jsx(View, {
                style: [cellStyle, isHeader && headerStyle, {
                  width: colWidth
                }, borderStyle && {
                  borderTopWidth: borderStyle.borderWidth,
                  borderLeftWidth: borderStyle.borderWidth,
                  borderBottomWidth: borderStyle.borderWidth,
                  borderRightWidth: borderStyle.borderWidth,
                  borderColor: borderStyle.borderColor
                }],
                children: /*#__PURE__*/_jsx(Cell, {
                  data: cellData,
                  width: colWidth,
                  textStyle: [textStyle, isHeader && headerTextStyle],
                  borderStyle: {
                    borderWidth: 0
                  } // no borders for inner cell
                })
              }, `cell-${rowIndex}-${cellIndex}`);
            })
          }, `row-${rowIndex}`);
        })
      })
    })]
  });
};
const styles = StyleSheet.create({
  container: {
    flexDirection: 'row'
  },
  stickyColumn: {
    zIndex: 1,
    elevation: 3
  },
  scrollView: {
    flex: 1
  },
  row: {
    flexDirection: 'row'
  }
});
//# sourceMappingURL=sticky-table.js.map