import { useMemo } from 'react';
import type { FC, PropsWithChildren } from 'react';
import { View, Text, StyleSheet, Pressable } from 'react-native';
import type { ViewStyle } from 'react-native';
import type { CellProps } from '../types';

/**
 * cell component - the basic building block of the table
 */
export const Cell: FC<PropsWithChildren<CellProps>> = ({
  data,
  width,
  height,
  flex,
  style,
  textStyle,
  borderStyle,
  children,
  onPress,
  cellContainer = {},
  ...props
}) => {
  const textDom = children ?? (
    <Text style={StyleSheet.flatten([textStyle])} {...props}>
      {data}
    </Text>
  );

  const borderTopWidth = borderStyle?.borderWidth ?? 0;
  const borderRightWidth = borderTopWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';

  const composedStyles = useMemo(() => {
    const styles: ViewStyle = {};
    if (width) styles.width = width;

    if (height) styles.height = height;

    if (flex) styles.flex = flex;

    if (!width && !flex && !height && !style) styles.flex = 1;

    return styles;
  }, [width, height, flex, style]);

  // determine whether to apply flex: 1 to cell style
  const cellStyle = useMemo(() => {
    if (width) {
      return {};
    }
    return styles.cell;
  }, [width]);

  return (
    <View
      {...cellContainer}
      style={StyleSheet.flatten([
        {
          borderTopWidth,
          borderRightWidth,
          borderColor,
        },
        composedStyles,
        style,
        cellContainer.style,
        cellStyle,
      ])}
    >
      <Pressable style={[styles.cell, style]} onPress={() => onPress?.(data)}>
        {textDom}
      </Pressable>
    </View>
  );
};

const styles = StyleSheet.create({
  cell: { flex: 1 },
});
