import type { FC } from 'react';
import React from 'react';
import { View } from 'react-native';

import type { TableProps, TableWrapperProps } from '../types';

export const Table: FC<TableProps> = ({ style, borderStyle, children }) => {
  const borderLeftWidth = borderStyle?.borderWidth ?? 0;
  const borderBottomWidth = borderLeftWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';

  const renderChildren = () =>
    React.Children.map(children, (child: any) =>
      React.cloneElement(
        child,
        borderStyle && child.type.displayName !== 'ScrollView'
          ? { borderStyle }
          : {}
      )
    );

  return (
    <View
      style={[
        style,
        {
          borderLeftWidth,
          borderBottomWidth,
          borderColor,
        },
      ]}
    >
      {renderChildren()}
    </View>
  );
};

export const TableWrapper: FC<TableWrapperProps> = ({
  style,
  borderStyle,
  children,
}) => {
  const renderChildren = () =>
    React.Children.map(children, (child: any) =>
      React.cloneElement(child, borderStyle ? { borderStyle } : {})
    );

  return <View style={style}>{renderChildren()}</View>;
};
